@@ -1,6 +1,8 @@
+mod cargo;
 pub mod configuration;
 mod format_text;
 mod parser;
+mod rowan_extensions;
 
 pub use format_text::format_text;
 
